Test WaitFor

First test waitForValue

Test WaitForValue
open | ../tests/html/test_async_event.html |
assertValue | theField | oldValue
click | theButton |
assertValue | theField | oldValue
waitForValue | theField | regexp:n[aeiou]wValue
verifyValue | theField | newValue

Test waitForText

assertText | theSpan | Some text
click | theSpanButton |
assertText | theSpan | Some text
waitForText | theSpan | regexp:Some n[aeiou]w text
verifyText | theSpan | Some new text

Test waiting for an alert.

click | theAlertButton |
waitForAlert | regexp:An [aeiou]lert |

Test for waiting for something on a new page.

open | ../tests/html/test_reload_onchange_page.html |
click | theLink |
waitForTitle | Slow Loading Page |
verifyTitle | Slow Loading Page |

Test for waiting for something that never arrives

setTimeout | 500 |
assertFailureOnNext | Timed out after 500ms |
waitForTextPresent | thisTextIsNotPresent |